@@ -1,5 +1,5 @@
 //
-// Copyright (C) 2013-2017 Codership Oy <info@codership.com>
+// Copyright (C) 2013-2019 Codership Oy <info@codership.com>
 //
 
 
@@ -8,6 +8,7 @@
 #include <gu_time.h>
 #include <gu_macros.hpp>
 #include <gu_utils.hpp>
+#include <gu_thread_keys.hpp>
 #ifndef NDEBUG
 #include <gcache_memops.hpp> // gcache::MemOps::ALIGNMENT
 #endif
@@ -101,14 +102,18 @@ WriteSetNG::Header::gather (KeySet::Version const  kver,
 
 
 void
-WriteSetNG::Header::set_last_seen(const wsrep_seqno_t& last_seen)
+WriteSetNG::Header::finalize(wsrep_seqno_t const last_seen,
+                             int const           pa_range)
 {
     assert (ptr_);
     assert (size_ > 0);
+    assert (pa_range >= -1);
 
-    uint64_t*   const ls  (reinterpret_cast<uint64_t*>(ptr_ +V3_LAST_SEEN_OFF));
-    uint64_t*   const ts  (reinterpret_cast<uint64_t*>(ptr_ +V3_TIMESTAMP_OFF));
+    uint16_t* const pa(reinterpret_cast<uint16_t*>(ptr_ + V3_PA_RANGE_OFF));
+    uint64_t* const ls(reinterpret_cast<uint64_t*>(ptr_ + V3_LAST_SEEN_OFF));
+    uint64_t* const ts(reinterpret_cast<uint64_t*>(ptr_ + V3_TIMESTAMP_OFF));
 
+    *pa = gu::htog<uint16_t>(std::min(int(MAX_PA_RANGE), pa_range));
     *ls = gu::htog<uint64_t>(last_seen);
     *ts = gu::htog<uint64_t>(gu_time_monotonic());
 
@@ -117,17 +122,21 @@ WriteSetNG::Header::set_last_seen(const wsrep_seqno_t& last_seen)
 
 
 void
-WriteSetNG::Header::set_seqno(const wsrep_seqno_t& seqno,
-                              uint16_t const pa_range)
+WriteSetNG::Header::set_seqno(wsrep_seqno_t const seqno,
+                              uint16_t      const pa_range)
 {
     assert (ptr_);
     assert (size_ > 0);
     assert (seqno > 0);
+    assert (wsrep_seqno_t(pa_range) <= seqno);
 
+    uint16_t* const fl(reinterpret_cast<uint16_t*>(ptr_ + V3_FLAGS_OFF));
     uint16_t* const pa(reinterpret_cast<uint16_t*>(ptr_ + V3_PA_RANGE_OFF));
     uint64_t* const sq(reinterpret_cast<uint64_t*>(ptr_ + V3_SEQNO_OFF));
 
-    *pa = gu::htog<uint16_t>(pa_range);
+    uint16_t  const flags(gu::htog<uint16_t>(*fl));
+    *fl = gu::htog<uint16_t>(flags | F_CERTIFIED); // certification happened
+    *pa = gu::htog<uint16_t>(pa_range);            // certification outcome
     *sq = gu::htog<uint64_t>(seqno);
 
     update_checksum (ptr_, size() - V3_CHECKSUM_SIZE);
@@ -212,8 +221,11 @@ WriteSetIn::init (ssize_t const st)
         if (size_ >= st)
         {
             /* buffer too big, start checksumming in background */
-            int const err(gu_thread_create (&check_thr_id_, NULL,
-                                            checksum_thread, this));
+            int const err(gu_thread_create (
+                              gu::get_thread_key(
+                                  gu::GU_THREAD_KEY_WRITE_SET_CHECK),
+                              &check_thr_id_,
+                              checksum_thread, this));
 
             if (gu_likely(0 == err))
             {
