@@ -310,11 +310,12 @@ GALERA_SRC=${GALERA_SRC:-$BUILD_ROOT/../../}
 MYSQL_SRC=$(cd $MYSQL_SRC; pwd -P; cd $BUILD_ROOT)
 GALERA_SRC=$(cd $GALERA_SRC; pwd -P; cd $BUILD_ROOT)
 
+MYSQL_BUILD_DIR="$MYSQL_SRC/build/"
 if [ "$DEBUG" == "yes" ]
 then
-    MYSQL_BUILD_DIR="$MYSQL_SRC/build_debug"
+    MYSQL_BUILD_SUBDIR="$MYSQL_BUILD_DIR/debug"
 else
-    MYSQL_BUILD_DIR="$MYSQL_SRC/build_release"
+    MYSQL_BUILD_SUBDIR="$MYSQL_BUILD_DIR/release"
 fi
 
 ######################################
@@ -377,7 +378,7 @@ then
         cd $mysql_tag/
     fi
     MYSQL_SRC=$(pwd -P)
-    MYSQL_BUILD_DIR=$MYSQL_SRC
+    MYSQL_BUILD_SUBDIR=$MYSQL_SRC
     if [ "$CONFIGURE" == "yes" ]
     then
         echo "Regenerating config files"
@@ -431,7 +432,7 @@ then
             CMAKE_LAYOUT_OPTIONS=( \
                 -DINSTALL_LAYOUT=RPM \
                 -DCMAKE_INSTALL_PREFIX="/usr" \
-                -DINSTALL_SBINDIR="/usr/sbin" \
+                -DINSTALL_SBINDIR="sbin" \
                 -DMYSQL_DATADIR="/var/lib/mysql" \
                 -DMYSQL_UNIX_ADDR=$MYSQL_SOCKET_PATH \
                 -DCMAKE_OSX_ARCHITECTURES=$(uname -m) \
@@ -471,9 +472,13 @@ then
             fi
             if [ "$MYSQL_MM_VER" -ge "57" ]
             then
-                BUILD_OPT+=" -DWITH_BOOST=boost_$MYSQL_MM_VER"
+                BUILD_OPT+=" -DWITH_BOOST=$MYSQL_BUILD_DIR/boost_$MYSQL_MM_VER"
                 [ "yes" = "$BOOTSTRAP" ] && BUILD_OPT+=" -DDOWNLOAD_BOOST=1"
             fi
+            if [ "$MYSQL_MM_VER" -ge "80" ]
+            then
+                BUILD_OPT+=" -DWITH_CURL=system"
+            fi
         else # MariaDB-specific build options
             BUILD_OPT+=" -DWITH_READLINE=system"
             BUILD_OPT+=" -DWITH_DEBUG:BOOL=ON"
@@ -489,13 +494,13 @@ then
             BUILD_OPT+=" -DWITH_EMBEDDED_SERVER:BOOL=OFF"
         fi
 
-        if [ "$MYSQL_BUILD_DIR" != "$MYSQL_SRC" ]
+        if [ "$MYSQL_BUILD_SUBDIR" != "$MYSQL_SRC" ]
         then
-           [ "$BOOTSTRAP" = "yes" ] && rm -rf $MYSQL_BUILD_DIR
-           [ -d "$MYSQL_BUILD_DIR" ] || mkdir -p $MYSQL_BUILD_DIR
+           [ "$BOOTSTRAP" = "yes" ] && rm -rf $MYSQL_BUILD_SUBDIR
+           [ -d "$MYSQL_BUILD_SUBDIR" ] || mkdir -p $MYSQL_BUILD_SUBDIR
         fi
 
-        pushd $MYSQL_BUILD_DIR
+        pushd $MYSQL_BUILD_SUBDIR
 
         # cmake wants either absolute path or a link from build directory
         # Incidentally link trick also allows us to use ccache
@@ -519,7 +524,7 @@ then
         && make VERBOSE=1 -j $JOBS -S && popd || exit 1
 
     else  # just recompile and relink with old configuration
-        pushd $MYSQL_BUILD_DIR
+        pushd $MYSQL_BUILD_SUBDIR
         CC=$(pwd)/$(basename $CC) CXX=$(pwd)/$(basename $CXX) \
         make -j $JOBS -S > /dev/null
         popd
@@ -543,7 +548,7 @@ install_mysql_5.5_dist()
 {
     export DESTDIR=$BUILD_ROOT/dist/mysql
     mkdir -p $DESTDIR
-    pushd $MYSQL_BUILD_DIR
+    pushd $MYSQL_BUILD_SUBDIR
     make install
     popd
     unset DESTDIR
@@ -553,7 +558,7 @@ install_mysql_5.5_demo()
 {
     export DESTDIR=$BUILD_ROOT/dist/mysql
     mkdir -p $DESTDIR
-    pushd $MYSQL_BUILD_DIR
+    pushd $MYSQL_BUILD_SUBDIR
     cmake -DCMAKE_INSTALL_COMPONENT=Server -P cmake_install.cmake
     cmake -DCMAKE_INSTALL_COMPONENT=Client -P cmake_install.cmake
     cmake -DCMAKE_INSTALL_COMPONENT=SharedLibraries -P cmake_install.cmake
@@ -585,7 +590,7 @@ if [ $TAR == "yes" ]; then
     install -m 755 -d $(dirname $MYSQL_DIST_CNF)
     install -m 644 my-5.5.cnf $MYSQL_DIST_CNF
 
-    cat $MYSQL_BUILD_DIR/support-files/wsrep.cnf | \
+    cat $MYSQL_BUILD_SUBDIR/support-files/wsrep.cnf | \
         sed 's/root:$/root:rootpass/' >> $MYSQL_DIST_CNF
     pushd $MYSQL_BINS;
     [ -x wsrep_sst_rsync_wan ] || ln -s wsrep_sst_rsync wsrep_sst_rsync_wan
@@ -762,7 +767,7 @@ build_freebsd_packages()
     install -m 755 -d $(dirname $MYSQL_DIST_CNF)
     install -m 644 my-5.5.cnf $MYSQL_DIST_CNF
 
-    cat $MYSQL_BUILD_DIR/support-files/wsrep.cnf | \
+    cat $MYSQL_BUILD_SUBDIR/support-files/wsrep.cnf | \
         sed 's/root:$/root:rootpass/' >> $MYSQL_DIST_CNF
     pushd $MYSQL_BINS; ln -s wsrep_sst_rsync wsrep_sst_rsync_wan; popd
 
